.. _source:


.. raw:: html

    </center>
    <br>

.. title:: Source


.. raw:: html

    <center><b>SOURCE</b></center>
    <br>


**GENOCIDE**


.. autosummary::
    :toctree: 
    :template: base.rst


    sbn.broker		list of bots
    sbn.client		clients
    sbn.disk		storage
    sbn.find		locate
    sbn.handler		event handler
    sbn.log		logging
    sbn.object		clean namespace
    sbn.run		runtime
    sbn.thread		threads


**MODULES**


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd	list of commands
    sbn.modules.err	show errors
    sbn.modules.irc	internet realy chat
    sbn.modules.log	log text
    sbn.modules.mod	list of modules
    sbn.modules.req	request
    sbn.modules.rss	rich site syndicate
    sbn.modules.tdo	todo items
    sbn.modules.thr	list of threads
    sbn.modules.tmr	timers
